/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/


#include <localsys.h>
#include <stdlib.h>
#include <ut_defs.h>

void F_GETPPS( pid,ppid )

                     /* routine to return the parent process id - pid   */
                     /*            and the child process id - ppid      */
                     /*            as integers                          */
/*   fortran call:      call getpps ( pid, ppid)                        */
/*   where   pid and ppid  are declared integers                        */

int *pid;
int *ppid;
{
        void C_GETPPS();
        C_GETPPS(pid,ppid);
}

/*
     put in C-callable entry point which is called by above
     fortran entry points.
*/
void C_GETPPS(pid,ppid)
int *pid;
int *ppid;
{
	if (getenv("USP_PRINT_BYPASS") != NULL) {
	  *pid=-1;
	  *ppid=-1;
	  }
	else {
	  *pid=getpid();
	  *ppid=getppid();
	  }
}
